package com.rjconsultores.ventaboletos.web.gui.controladores.catalogos;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Paging;

import com.rjconsultores.ventaboletos.entidad.Empleado;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.MyTextbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderEmpleado;

@Controller("busquedaEmpleadoController")
@Scope("prototype")
public class BusquedaEmpleadoController  extends MyGenericForwardComposer {
	
	private static final long serialVersionUID = 1L;
	
	@Autowired
	private transient PagedListWrapper<Empleado> plwEmpleado;
	private MyListbox empleadoList;
	private Paging pagingEmpleado;
	private MyTextbox txtNombEmpleado;
	private MyTextbox txtApelidoPaterno;
	private MyTextbox txtApelidoMaterno;
	private MyTextbox txtCveEmpleado;
	
	@Override
	public void doAfterCompose(Component comp) throws Exception {

		super.doAfterCompose(comp);

		empleadoList.setItemRenderer(new RenderEmpleado());
		empleadoList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				Empleado e = (Empleado) empleadoList.getSelected();
				verEmpleado(e);
			}
		});

		refreshLista();
	}

	public void onClick$btnPesquisa(Event ev) {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) {
		verEmpleado(new Empleado());
	}
	
	private void refreshLista() {
		HibernateSearchObject<Empleado> sistemaBusqueda =
				new HibernateSearchObject<Empleado>(Empleado.class, pagingEmpleado.getPageSize());

		String cveEmpleado = txtCveEmpleado.getValue();
		if (cveEmpleado != null && StringUtils.isNotBlank(cveEmpleado)) {
			sistemaBusqueda.addFilterLike("cveEmpleado", "%".concat(cveEmpleado.trim().concat("%")));
		}
		
		String nombempleado = txtNombEmpleado.getText();
		if (nombempleado != null && StringUtils.isNotBlank(nombempleado)) {
			sistemaBusqueda.addFilterLike("nombEmpleado", "%" + nombempleado.trim().concat("%"));
		}

		String apellidopaterno = txtApelidoPaterno.getText();
		if (apellidopaterno != null && StringUtils.isNotBlank(apellidopaterno)) {
			sistemaBusqueda.addFilterLike("nombPaterno", "%" + apellidopaterno.trim().concat("%"));
		}

		String apellidomaterno = txtApelidoMaterno.getText();
		if (apellidomaterno != null && StringUtils.isNotBlank(apellidomaterno)) {
			sistemaBusqueda.addFilterLike("nombMaterno", "%" + apellidomaterno.trim().concat("%"));
		}

		sistemaBusqueda.addFilterEqual("activo", Boolean.TRUE);
		sistemaBusqueda.addSortAsc("nombEmpleado");
		sistemaBusqueda.addFilterNotEqual("empleadoId", -1);

		plwEmpleado.init(sistemaBusqueda, empleadoList, pagingEmpleado);

		if (empleadoList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("busquedaEmpleadoController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
	}
	
	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void verEmpleado(Empleado e) {
		if (e == null) {
			return;
		}

		Map args = new HashMap();
		args.put("empleado", e);
		args.put("empleadoList", empleadoList);

		openWindow("/gui/catalogos/editarEmpleado.zul",
				Labels.getLabel("editarEmpleadoController.window.title"), args, MODAL);
	}

	public MyListbox getEmpleadoList() {
		return empleadoList;
	}

	public void setEmpleadoList(MyListbox empleadoList) {
		this.empleadoList = empleadoList;
	}

	public MyTextbox getTxtNombEmpleado() {
		return txtNombEmpleado;
	}

	public void setTxtNombEmpleado(MyTextbox txtNombEmpleado) {
		this.txtNombEmpleado = txtNombEmpleado;
	}

	public MyTextbox getTxtApelidoPaterno() {
		return txtApelidoPaterno;
	}

	public void setTxtApelidoPaterno(MyTextbox txtApelidoPaterno) {
		this.txtApelidoPaterno = txtApelidoPaterno;
	}

	public MyTextbox getTxtApelidoMaterno() {
		return txtApelidoMaterno;
	}

	public void setTxtApelidoMaterno(MyTextbox txtApelidoMaterno) {
		this.txtApelidoMaterno = txtApelidoMaterno;
	}

	public MyTextbox getTxtCveEmpleado() {
		return txtCveEmpleado;
	}

	public void setTxtCveEmpleado(MyTextbox txtCveEmpleado) {
		this.txtCveEmpleado = txtCveEmpleado;
	}
	
	
}
